@@ -1,7 +1,7 @@
 poisson.param <-
-function(thr)
+function(thr, upper.copy)
 {
-lamda=c(seq(0.01, 0.09, 0.01), seq(0.1,20,0.1))
+lamda=c(seq(0.01, 0.09, 0.01), seq(0.1,9.9,0.1), seq(10,upper.copy,1))
 th=seq(1,10,1)
 if (thr){
 th=1
